@@ -21,16 +21,21 @@ def ScrollBar(root, widget, side="right", fill="y"):
     scrollbar.pack(side=side, fill=fill)
     a.config(yscrollcommand=scrollbar.set)
 
-def Label(parent, text="Default Text", font="Helvetica", size=12, color="black", wraplenght=2):
-    label = ttk.Label(parent, text=text,  font = (font, size), foreground = color, wraplength=wraplenght); label.pack(); 
+def Label(parent, textvariabl, text="Default Text", font="Helvetica", size=12, color="black", wraplenght=2):
+    label = ttk.Label(parent, text=text,  font = (font, size), foreground = color, wraplength=wraplenght, textvariable=textvariabl)
     return label
 
+    
+
 def Place(widget, x, y):
     widget.place(x=x, y=y)
 
 def Font(name = 'arial', size = 20, weight = "bold"):
     font = tkfont.Font(name = name, size = size, weight = weight)
     return font
+def StrVar():
+    v = tk.StringVar()
+    return v
 
 def OpenFile(title):
     file_path = filedialog.askopenfilename(title="Select a file")
@@ -64,7 +69,7 @@ def Entry(parent, width=20, font="Helvetica", size=12, bg="white", fg="black"):
 
 def GetEntry(entry):
     d = entry.get()
-    return entry 
+    return d 
 
 def Design(theme):
     style = Style(theme=theme)
@@ -97,9 +102,5 @@ def Entry(parent, width=20, font="Helvetica", size=12, bg="white", fg="black", p
     entry.pack(padx=padx, pady=pady)
     return entry
 
-def GetEntry(entry):
-    d = entry.get()
-    return entry 
-
 def Run(window):
     window.mainloop()
\ No newline at end of file
