@@ -15,6 +15,7 @@ from .FunctionGUI import (
     ChexBox,
     add,
     Design,
-    ScrollBar
+    ScrollBar,
+    StrVar
 
 )
